==> sal-activity-2.8.0-20161209.105845-32-sources.jar: com/baijia/tianxiao/sal/marketing/activity/dto/ActivityConfigDto.java <==
package com.baijia.tianxiao.sal.marketing.activity.dto;

/**
 * @author Rezar
 * @createDate :Jan 10, 2016 10:47:30 PM
 * @desc :
 */
public class ActivityConfigDto {

    // 活动开始时间
    private Long startTime;

    // 活动结束时间
    private Long endTime;

    // 报名人数限制：-1=无限制
    private Integer countLimit;

    // 是否在机构主页显示:0=显示，1=不显示
    private int display;

    // 报名结束时间
    private Long enrollDeadline;

    // 经度
    private String longitude;

    // 维度
    private String latitude;

    // 活动地址
    private String address;

    // 地域ID
    private Integer areaId;

    // 自定义配置信息
    private String customConf;

    private Integer templateId; // 模板id

    private Integer templateTypeId;

    public Long getStartTime() {
        return startTime;
    }

    public void setStartTime(Long startTime) {
        this.startTime = startTime;
    }

    public Long getEndTime() {
        return endTime;
    }

    public void setEndTime(Long endTime) {
        this.endTime = endTime;
    }

    public Long getEnrollDeadline() {
        return enrollDeadline;
    }

    public void setEnrollDeadline(Long enrollDeadline) {
        this.enrollDeadline = enrollDeadline;
    }

    public Integer getCountLimit() {
        return countLimit;
    }

    public void setCountLimit(Integer countLimit) {
        this.countLimit = countLimit;
    }

    public int getDisplay() {
        return display;
    }

    public void setDisplay(int display) {
        this.display = display;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Integer getAreaId() {
        return areaId;
    }

    public void setAreaId(Integer areaId) {
        this.areaId = areaId;
    }

    public String getCustomConf() {
        return customConf;
    }

    public void setCustomConf(String customConf) {
        this.customConf = customConf;
    }

    public void setTemplateId(Integer templateId) {
        this.templateId = templateId;
    }

    public Integer getTemplateId() {
        return templateId;
    }

    public Integer getTemplateTypeId() {
        return this.templateTypeId;
    }

    public void setTemplateTypeId(Integer templateTypeId) {
        this.templateTypeId = templateTypeId;
    }

}

==> sal-activity-2.24.0-20170428.061447-35-sources.jar: com/baijia/tianxiao/sal/marketing/activity/dto/ActivityConfigDto.java <==
package com.baijia.tianxiao.sal.marketing.activity.dto;

/**
 * @author Rezar
 * @createDate :Jan 10, 2016 10:47:30 PM
 * @desc :
 */
public class ActivityConfigDto {

    // 活动开始时间
    private Long startTime;

    // 活动结束时间
    private Long endTime;

    // 报名人数限制：-1=无限制
    private Integer countLimit;

    // 是否在机构主页显示:0=显示，1=不显示
    private int display;

    // 报名结束时间
    private Long enrollDeadline;

    // 经度
    private String longitude;

    // 维度
    private String latitude;

    // 活动地址
    private String address;

    // 地域ID
    private Long areaId;

    // 自定义配置信息
    private String customConf;

    private Integer templateId; // 模板id

    private Integer templateTypeId;

    public Long getStartTime() {
        return startTime;
    }

    public void setStartTime(Long startTime) {
        this.startTime = startTime;
    }

    public Long getEndTime() {
        return endTime;
    }

    public void setEndTime(Long endTime) {
        this.endTime = endTime;
    }

    public Long getEnrollDeadline() {
        return enrollDeadline;
    }

    public void setEnrollDeadline(Long enrollDeadline) {
        this.enrollDeadline = enrollDeadline;
    }

    public Integer getCountLimit() {
        return countLimit;
    }

    public void setCountLimit(Integer countLimit) {
        this.countLimit = countLimit;
    }

    public int getDisplay() {
        return display;
    }

    public void setDisplay(int display) {
        this.display = display;
    }

    public String getLongitude() {
        return longitude;
    }

    public void setLongitude(String longitude) {
        this.longitude = longitude;
    }

    public String getLatitude() {
        return latitude;
    }

    public void setLatitude(String latitude) {
        this.latitude = latitude;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public Long getAreaId() {
        return areaId;
    }

    public void setAreaId(Long areaId) {
        this.areaId = areaId;
    }

    public String getCustomConf() {
        return customConf;
    }

    public void setCustomConf(String customConf) {
        this.customConf = customConf;
    }

    public void setTemplateId(Integer templateId) {
        this.templateId = templateId;
    }

    public Integer getTemplateId() {
        return templateId;
    }

    public Integer getTemplateTypeId() {
        return this.templateTypeId;
    }

    public void setTemplateTypeId(Integer templateTypeId) {
        this.templateTypeId = templateTypeId;
    }

}
